@@ -41,6 +41,8 @@
 
 #include "gdmgreeter.h"
 
+static const gchar RCSid[]="$Id: gdmgreeter.c,v 1.48 1999/01/27 22:11:26 mkp Exp $";
+
 extern gchar * gdm_parse_enriched_string(gchar *str);
 extern gboolean gdm_file_check(gchar *caller, uid_t user, gchar *dir, gchar *file, gboolean absentok);
 
@@ -118,9 +120,6 @@ GSList *languages=NULL;
 static void
 gdm_greeter_done(void)
 {
-    close(0);
-    close(1);
-    close(2);
     closelog();
     gtk_main_quit();
 }
@@ -273,18 +272,36 @@ gdm_greeter_query(gchar *msg)
 }
 
 
+static void
+gdm_greeter_info_handler(GtkWidget *widget, GtkWidget *dialog)
+{
+    GdkCursor *cursor;
+
+    g_print("foo");
+    cursor=gdk_cursor_new(GDK_LEFT_PTR);
+    gdk_window_set_cursor (gdmMain->window, cursor);
+    gdk_cursor_destroy(cursor);
+    gtk_widget_set_sensitive (gdmMain, TRUE);
+}
+
+
 static void
 gdm_greeter_info(gchar *msg)
 {
     GtkWidget *req;
 
     req=gnome_message_box_new(msg,
-			      GNOME_MESSAGE_BOX_INFO,
-			      GNOME_STOCK_BUTTON_OK,
-			      NULL);
-	    
+                              GNOME_MESSAGE_BOX_INFO,
+                              GNOME_STOCK_BUTTON_OK,
+                              NULL);
+
+    gnome_dialog_button_connect(GNOME_DIALOG(req),
+				0,
+				gdm_greeter_info_handler,
+				NULL);
+
     gtk_window_set_modal(GTK_WINDOW(req), TRUE);
-    gnome_dialog_run(GNOME_DIALOG(req));
+    gtk_widget_show_all(req);
 }
 
 
@@ -309,7 +326,7 @@ gdm_greeter_login (GtkWidget *widget, gpointer data)
 }
 
 
-static gboolean
+static void
 gdm_greeter_sesslang_send(void)
 {
     gboolean savesess=FALSE, savelang=FALSE;
@@ -373,19 +390,13 @@ gdm_greeter_sesslang_send(void)
     else
 	savelang=TRUE;
 
-    if(!strcasecmp(curlang, "english"))
-       curlang=g_strdup("C");
-
     g_print("%c%s\n%d\n%s\n%d\n", 0x3, cursess, savesess, curlang, savelang);
-
-    return(TRUE);
 }
 
 
-static gboolean
+static void
 gdm_greeter_invalid_passwd_req (void) 
 {
-    GdkCursor *cursor;
     int i;
     int x,y;
 
@@ -403,13 +414,7 @@ gdm_greeter_invalid_passwd_req (void)
 
     gdm_greeter_info(_("Invalid username or password!"));
 
-    cursor=gdk_cursor_new(GDK_LEFT_PTR);
-    gdk_window_set_cursor (gdmMain->window, cursor);
-    gdk_cursor_destroy(cursor);
-    gtk_widget_set_sensitive (gdmMain, TRUE);
     gtk_window_set_focus(GTK_WINDOW (greeter), passwdentry);
-
-    return(TRUE);
 }
 
 
@@ -781,7 +786,7 @@ gdm_greeter_session_init(GtkWidget *parent)
 	gdm_greeter_abort(_("No session scripts found. Aborting!"));
 
     if(!defsess) {
-	defsess=g_slist_nth_data(sessions, 0);
+	gtk_label_get(GTK_LABEL(GTK_BIN(g_slist_nth_data(sessions, 0))->child), &defsess);
 	syslog(LOG_WARNING, _("No default session link found. Using %s.\n"), defsess);
     }
 
@@ -1559,7 +1564,7 @@ main (int argc, char *argv[])
     gtk_widget_show_all(greeter);
 
     hup.sa_handler = (void *) gdm_greeter_done;
-    hup.sa_flags = SA_RESTART;
+    hup.sa_flags = 0;
     sigemptyset(&hup.sa_mask);
 
     if(sigaction(SIGHUP, &hup, NULL) < 0) 
@@ -1574,6 +1579,7 @@ main (int argc, char *argv[])
     usr1.sa_handler = (void *) gdm_greeter_invalid_passwd_req;
     usr1.sa_flags = SA_RESTART;
     sigemptyset(&usr1.sa_mask);
+    sigaddset(&usr2.sa_mask, SIGUSR2);
 
     if(sigaction(SIGUSR1, &usr1, NULL) < 0) 
         gdm_greeter_abort(_("main: Error setting up USR1 signal handler"));
@@ -1581,6 +1587,7 @@ main (int argc, char *argv[])
     usr2.sa_handler = (void *) gdm_greeter_sesslang_send;
     usr2.sa_flags = SA_RESTART;
     sigemptyset(&usr2.sa_mask);
+    sigaddset(&usr2.sa_mask, SIGUSR1);
 
     if(sigaction(SIGUSR2, &usr2, NULL) < 0)
         gdm_greeter_abort(_("main: Error setting up USR2 signal handler"));
